package com.xkrs.service.impl;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.dao.FireDao;
import com.xkrs.model.entity.Fire;
import com.xkrs.service.FireService;
import org.springframework.cache.annotation.CacheConfig;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/2/11 8:52
 */
@Service
@CacheConfig(cacheNames = "FireServiceCache")
public class FireServerImpl implements FireService {

    @Resource
    private FireDao fireDao;

    Locale locale = LocaleContextHolder.getLocale();


    /**
     * 根据设备编码获取火情的信息
     * @param code
     * @return
     */
    @Cacheable(keyGenerator = "keyGenerator",unless="#result == null")
    @Override
    public String getFireInformation(String code) {
        List<Fire> byDeviceCode = fireDao.findByDeviceCode(code);
        if(byDeviceCode == null || byDeviceCode.size() == 0){
            return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"暂时没有该设备的火情信息！",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,byDeviceCode,locale);
    }
}
